==> xlniuxdata-vipgame-1.0.18-20150713.071534-2-sources.jar: com/xunlei/niux/data/vipgame/vo/CheatingReport.java <==
package com.xunlei.niux.data.vipgame.vo;

import com.ferret.common.dao.annotation.Table;

@Table(tableName = "cheating_report", pkFieldName = "seqid", pkFieldAssign = false)
public class CheatingReport {
    private Long seqid;
    private String  providerGameId;
    private String  providerServerId;
    private String  providerRoleName;
    private String  providerUserId;
    private String  reportTime;
    private String  CheaterGameId;
    private String  CheaterServerId;
    private String  CheaterRoleName;
    private String  timeOfCheating;
    private String  descOfCheating;
    private String  videoOfCheating;
    private String  urlOfCheating;
    private String  handler;
    private String  handleTime;
    private String  handleDesc;
    private Integer  status;
    private Long  lockSeconds;

    public String getCheaterGameId() {
        return CheaterGameId;
    }

    public void setCheaterGameId(String cheaterGameId) {
        CheaterGameId = cheaterGameId;
    }

    public String getCheaterRoleName() {
        return CheaterRoleName;
    }

    public void setCheaterRoleName(String cheaterRoleName) {
        CheaterRoleName = cheaterRoleName;
    }

    public String getCheaterServerId() {
        return CheaterServerId;
    }

    public void setCheaterServerId(String cheaterServerId) {
        CheaterServerId = cheaterServerId;
    }

    public String getDescOfCheating() {
        return descOfCheating;
    }

    public void setDescOfCheating(String descOfCheating) {
        this.descOfCheating = descOfCheating;
    }

    public String getHandleDesc() {
        return handleDesc;
    }

    public void setHandleDesc(String handleDesc) {
        this.handleDesc = handleDesc;
    }

    public String getHandler() {
        return handler;
    }

    public void setHandler(String handler) {
        this.handler = handler;
    }

    public String getHandleTime() {
        return handleTime;
    }

    public void setHandleTime(String handleTime) {
        this.handleTime = handleTime;
    }

    public Long getLockSeconds() {
        return lockSeconds;
    }

    public void setLockSeconds(Long lockSeconds) {
        this.lockSeconds = lockSeconds;
    }

    public String getProviderGameId() {
        return providerGameId;
    }

    public void setProviderGameId(String providerGameId) {
        this.providerGameId = providerGameId;
    }

    public String getProviderRoleName() {
        return providerRoleName;
    }

    public void setProviderRoleName(String providerRoleName) {
        this.providerRoleName = providerRoleName;
    }

    public String getProviderServerId() {
        return providerServerId;
    }

    public void setProviderServerId(String providerServerId) {
        this.providerServerId = providerServerId;
    }

    public String getProviderUserId() {
        return providerUserId;
    }

    public void setProviderUserId(String providerUserId) {
        this.providerUserId = providerUserId;
    }

    public String getReportTime() {
        return reportTime;
    }

    public void setReportTime(String reportTime) {
        this.reportTime = reportTime;
    }

    public Long getSeqid() {
        return seqid;
    }

    public void setSeqid(Long seqid) {
        this.seqid = seqid;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public String getTimeOfCheating() {
        return timeOfCheating;
    }

    public void setTimeOfCheating(String timeOfCheating) {
        this.timeOfCheating = timeOfCheating;
    }

    public String getUrlOfCheating() {
        return urlOfCheating;
    }

    public void setUrlOfCheating(String urlOfCheating) {
        this.urlOfCheating = urlOfCheating;
    }

    public String getVideoOfCheating() {
        return videoOfCheating;
    }

    public void setVideoOfCheating(String videoOfCheating) {
        this.videoOfCheating = videoOfCheating;
    }
}

==> xlniuxdata-vipgame-1.0.18-20150714.084928-3-sources.jar: com/xunlei/niux/data/vipgame/vo/CheatingReport.java <==
package com.xunlei.niux.data.vipgame.vo;

import com.ferret.common.dao.annotation.Table;
import com.xunlei.common.util.Extendable;

@Table(tableName = "cheating_report", pkFieldName = "seqid", pkFieldAssign = false)
public class CheatingReport {
    private Long seqid;
    private String  providerGameId;
    private String  providerServerId;
    private String  providerRoleName;
    private String  providerUserId;
    private String  reportTime;
    private String  CheaterGameId;
    private String  CheaterServerId;
    private String  CheaterRoleName;
    private String  timeOfCheating;
    private String  descOfCheating;
    private String  videoOfCheating;
    private String  urlOfCheating;
    private String  handler;
    private String  handleTime;
    private String  handleDesc;
    private Integer  status;
    private Long  lockSeconds;
    @Extendable
    private String lockSecondsDisplay;

    public String getLockSecondsDisplay() {
        return lockSecondsDisplay;
    }

    public void setLockSecondsDisplay(String lockSecondsDisplay) {
        this.lockSecondsDisplay = lockSecondsDisplay;
    }

    public String getCheaterGameId() {
        return CheaterGameId;
    }

    public void setCheaterGameId(String cheaterGameId) {
        CheaterGameId = cheaterGameId;
    }

    public String getCheaterRoleName() {
        return CheaterRoleName;
    }

    public void setCheaterRoleName(String cheaterRoleName) {
        CheaterRoleName = cheaterRoleName;
    }

    public String getCheaterServerId() {
        return CheaterServerId;
    }

    public void setCheaterServerId(String cheaterServerId) {
        CheaterServerId = cheaterServerId;
    }

    public String getDescOfCheating() {
        return descOfCheating;
    }

    public void setDescOfCheating(String descOfCheating) {
        this.descOfCheating = descOfCheating;
    }

    public String getHandleDesc() {
        return handleDesc;
    }

    public void setHandleDesc(String handleDesc) {
        this.handleDesc = handleDesc;
    }

    public String getHandler() {
        return handler;
    }

    public void setHandler(String handler) {
        this.handler = handler;
    }

    public String getHandleTime() {
        return handleTime;
    }

    public void setHandleTime(String handleTime) {
        this.handleTime = handleTime;
    }

    public Long getLockSeconds() {
        return lockSeconds;
    }

    public void setLockSeconds(Long lockSeconds) {
        this.lockSeconds = lockSeconds;
    }

    public String getProviderGameId() {
        return providerGameId;
    }

    public void setProviderGameId(String providerGameId) {
        this.providerGameId = providerGameId;
    }

    public String getProviderRoleName() {
        return providerRoleName;
    }

    public void setProviderRoleName(String providerRoleName) {
        this.providerRoleName = providerRoleName;
    }

    public String getProviderServerId() {
        return providerServerId;
    }

    public void setProviderServerId(String providerServerId) {
        this.providerServerId = providerServerId;
    }

    public String getProviderUserId() {
        return providerUserId;
    }

    public void setProviderUserId(String providerUserId) {
        this.providerUserId = providerUserId;
    }

    public String getReportTime() {
        return reportTime;
    }

    public void setReportTime(String reportTime) {
        this.reportTime = reportTime;
    }

    public Long getSeqid() {
        return seqid;
    }

    public void setSeqid(Long seqid) {
        this.seqid = seqid;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public String getTimeOfCheating() {
        return timeOfCheating;
    }

    public void setTimeOfCheating(String timeOfCheating) {
        this.timeOfCheating = timeOfCheating;
    }

    public String getUrlOfCheating() {
        return urlOfCheating;
    }

    public void setUrlOfCheating(String urlOfCheating) {
        this.urlOfCheating = urlOfCheating;
    }

    public String getVideoOfCheating() {
        return videoOfCheating;
    }

    public void setVideoOfCheating(String videoOfCheating) {
        this.videoOfCheating = videoOfCheating;
    }
}
